@@ -126,6 +126,9 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
                 if file_path:
                     file_gen = None
                     filename = os.path.basename(file_path)
+                    new_file = os.path.join(recovery_path, filename)
+                    if os.path.exists(new_file) and not replace:
+                        return 128507, code_dict.get("128507"), ""
                     try:
                         file_gen = gen_file(file_path)
                     except FileNotFoundError:
@@ -136,11 +139,14 @@ def create_file(remote_path, x_type, req_url, file=None, filename=None,
                         logger.error(traceback.format_exc())
                         raise_(Exception, exc)
                     if file_gen:
-                        with open(os.path.join(recovery_path, filename), 'ab') as f:
+                        with open(new_file, 'wb') as f:
                             for fc in file_gen:
                                 f.write(fc)
                 else:
-                    with open(os.path.join(recovery_path, filename), 'ab') as f:
+                    new_file = os.path.join(recovery_path, filename)
+                    if os.path.exists(new_file) and not replace:
+                        return 128507, code_dict.get("128507"), ""
+                    with open(new_file, 'wb') as f:
                         f.write(file)
                 code = 0
                 err = code_dict.get("0")
